## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 24;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

%global pypi_name dask-expr
%global forgeurl https://github.com/dask/dask-expr

# dask-expr buildrequires dask, and dask buildrequires dask-expr
# this disables dask-expr's tests and excludes dask from the
# buildrequires, for breaking the loop when bootstrapping
%bcond bootstrap 1

# Tests require `distributed` and so does `dask_expr`. But that
# dependency is neither listed nor available, yet.
%bcond tests 0

Name:           python-%{pypi_name}
Version:        1.1.10
Release:        %autorelease -e 0.riscv64
Summary:        High Level Expressions for Dask
%forgemeta
License:        BSD-3-Clause
URL:            %forgeurl
Source:         %forgesource

BuildArch:      noarch
BuildRequires:  git-core
BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  python3dist(graphviz)
BuildRequires:  python3dist(pytest)
# https://github.com/dask/dask-expr/issues/1102
BuildRequires:  python3dist(xarray)
%endif

%global _description %{expand:
Dask Expressions - Dask DataFrames with query optimization.

This is a rewrite of Dask DataFrame that includes query optimization
and generally improved organization.}

%description %_description


%package -n python3-%{pypi_name}
Summary:        %{summary}
Recommends:     python3dist(distributed)

%description -n python3-%{pypi_name} %_description


%pyproject_extras_subpkg -n python3-%{pypi_name} analyze


%prep
%forgeautosetup -p1 -S git

%if %{with bootstrap}
# patch out the dask dependency so we can bootstrap it
sed -r -i '/(dask)[<=> ]+[0-9]+/d' pyproject.toml
%else
# Drop upper bound from dask
sed -r -i 's/(dask) *== *([0-9.]*)/\1 >= \2/' pyproject.toml
%endif

# Loosen version pinning on versioneer[toml]
sed -r -i 's/(versioneer\[toml\])[<=>]*/\1>=/' pyproject.toml

# Commit and tag for Versioneer
git add --all
git commit -m '[Fedora] Changes for RPM'
git tag v%{version}


%generate_buildrequires
%pyproject_buildrequires %{?with_tests:%{!?with_bootstrap:-x analyze}}


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l dask_expr


%check

%if %{with tests} && %{without bootstrap}

# Tests keep failing on `s390x`. Probably NumPy related.
# Since this is a noarch package, we cannot use %%ifarch
if [ "$(uname -m)" == "s390x" ]; then
  k="${k-}${k+ and }not test_combine_similar_no_projection_on_one_branch"
  k="${k-}${k+ and }not test_parquet_all_na_column"
fi
%pytest -v ${k+-k }"${k-}"

%endif


%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.md


%changelog
* Fri Aug 09 2024 David Abdurachmanov <davidlt@rivosinc.com> None-24
- Bootstrap (riscv64)

* Wed Aug 07 2024 Elliott Sales de Andrade <quantum.analyst@gmail.com> None-23
- Fix dask version pin sed

* Tue Aug 06 2024 Packit <hello@packit.dev> None-22
- Update to 1.1.10 upstream release

* Tue Aug 06 2024 Elliott Sales de Andrade <quantum.analyst@gmail.com> None-21
- Fix bootstrap mode

* Sat Jul 20 2024 Packit <hello@packit.dev> None-20
- Update to 1.1.9 upstream release

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> None-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue Jul 09 2024 Sandro <devel@penguinpee.nl> None-18
- Add BR for xarray

* Fri Jul 05 2024 Packit <hello@packit.dev> None-17
- Update to 1.1.7 upstream release

* Sat Jun 29 2024 Sandro <devel@penguinpee.nl> None-16
- Make skipped tests arch dependent

* Thu Jun 27 2024 Sandro <devel@penguinpee.nl> None-15
- Package analyze extra

* Wed Jun 26 2024 Sandro <devel@penguinpee.nl> None-14
- Add BR for distributed

* Fri Jun 21 2024 Sandro <devel@penguinpee.nl> None-13
- Drop patch (merged upstream)

* Fri Jun 21 2024 Packit <hello@packit.dev> None-12
- Update to 1.1.6 upstream release

* Wed Jun 19 2024 Sandro <devel@penguinpee.nl> None-11
- Skip tests that keep failing on s390x

* Wed Jun 19 2024 Sandro <devel@penguinpee.nl> None-10
- Apply patch excluding tests requiring `distributed`

* Wed Jun 19 2024 Sandro <devel@penguinpee.nl> None-9
- Loosen version pinning on versioneer[toml]

* Wed Jun 19 2024 Sandro <devel@penguinpee.nl> None-8
- Disable bootstrap, enable tests

* Wed Jun 19 2024 Sandro <devel@penguinpee.nl> None-7
- Revert "Build without bootstrap, but also without tests for now"

* Tue Jun 18 2024 Adam Williamson <awilliam@redhat.com> None-6
- Build without bootstrap, but also without tests for now

* Mon Jun 17 2024 Adam Williamson <awilliam@redhat.com> None-5
- Tweak the bootstrap implementation to be cleaner

* Mon Jun 17 2024 Adam Williamson <awilliam@redhat.com> None-4
- Filter dask dependency in bootstrap build

* Mon Jun 17 2024 Adam Williamson <awilliam@redhat.com> None-3
- Bump to 1.1.3, implement a bootstrap build to break dep loop

* Fri May 17 2024 Sandro <devel@penguinpee.nl> None-2
- Initial release (RHBZ#2280279)
